@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2020 Flavio Garcia
+# Copyright 2015-2021 Flavio Garcia
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,18 +14,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import (absolute_import, division, print_function,
-                        with_statement)
-
 from cartola import fs, security
 import firenado.conf
 from firenado.config import get_class_from_config
-
 import functools
 import logging
 import os
 import tornado
 import tornado.ioloop
+import tornado.web
 
 logger = logging.getLogger(__name__)
 
